﻿using System;
using System.Collections.ObjectModel;
using System.Linq;
using System.Collections.Generic;

namespace MangoDatabaseCreator
{
    public class MainViewModel
    {

        #region Fields

        private MangoDataContext mangoDb;

        #endregion


        #region Properties

        private List<Recipe> recipes;
        public List<Recipe> Recipes
        {
            get 
            {
                if (recipes == null)
                {
                    recipes = new List<Recipe>();
                }
                return recipes; 
            }
        }

        private List<Fact> facts;
        public List<Fact> Facts
        {
            get 
            {
                if (facts == null)
                {
                    facts = new List<Fact>();
                }
                return facts; 
            }
        }

        private List<Cocktail> cocktails;
        public List<Cocktail> Cocktails
        {
            get 
            {
                if (cocktails == null)
                {
                    cocktails = new List<Cocktail>();
                }
                return cocktails; 
            }
        }

        #endregion


        #region CreateDatabase

        public void CreateDatabase()
        {
            mangoDb = new MangoDataContext();
            if (!mangoDb.DatabaseExists())
            {
                mangoDb.CreateDatabase();
                CreateRecipes();
                CreateFacts();
                CreateCocktails();
            }
        }

        #endregion


        #region CreateRecipes

        private void CreateRecipes()
        {
            Recipes.Add(new Recipe
            {
                ID = 1,
                Name = "mango salsa fresca",
                Photo = "Images/Recipes/MangoSalsa.jpg", 
                Ingredients = "1 large mango, 1 medium red onion, 1 jalapeño, ½ pint cherry tomatoes, 9-12 sprigs cilantro (depending on size), 1 lime, salt.", 
                Instructions = "Peel and pit mango, and de-seed jalapeño. Chop mango, jalapeño , onion and cilantro and combine in a large bowl. Cut tomatoes in half and add to rest of ingredients. Squeeze in the juice from the lime, salt to taste and mix well. Set aside for at least a half hour to allow flavors to combine. Stir again before serving.", 
                Season = "spring"} );
            Recipes.Add(new Recipe { 
                ID = 2, 
                Name = "mango chutney", 
                Photo = "Images/Recipes/MangoChutney.jpg", 
                Ingredients = "3 large ripe but firm mangoes, 3 tablespoons olive oil, 1 teaspoon red chili flake, 1 tablespoon minced ginger, 2 cup diced red onion, 6 oz. pineapple juice, 3 oz. mango juice, 3 oz. cider vinegar, ½ cup cane sugar,  1 tablespoon garam masala, ½ cup sultanas, ½ cup dried and chopped apricots, ½ sliced almonds.", 
                Instructions = "In a bowl mix together the juice, vinegar, sugar and garam masala.  Cut the mango into ¼ inch pieces. Heat the oil and cook the chili flake for a few seconds. Add the onion and cook until barely translucent. Add the ginger and sauté for 1 minute, and then add the mango and sauté for 2 minutes longer. Deglaze pan with liquid mixture and reduce heat.  Simmer for 25 minutes. Add sultanas, apricots and almonds, and simmer for another 5 minutes before removing from heat. Transfer to a glass bowl and place inside a large bowl filled with ice and a little water in order to cool rapidly.", 
                Season = "winter"} );
            Recipes.Add(new Recipe { 
                ID = 3, 
                Name = "mango waffles", 
                Photo = "Images/Recipes/MangoWaffles.jpg", 
                Ingredients = "3 mangoes, 1 pint vanilla, coconut or tropical fruit ice cream/frozen yogurt. Waffles: 1 cup all-purpose flour, 1 cup wheat flour, 1 teaspoon baking powder, 3 tablespoons sugar, ½ teaspoon nutmeg, ½ teaspoon salt, 3 beaten eggs, 4 tablespoons melted and unsalted butter, 2 cups buttermilk, 1 tablespoon orange zest, vegetable spray for waffle iron.", 
                Instructions = "Preheat waffle iron. In a medium bowl, combine dry ingredients. In another bowl whisk eggs, melted butter and orange zest until well incorporated and then add buttermilk, continuing to whisk until completely blended. Add wet ingredients to dry and fold until combined. Allow batter to rest for five minutes and then cook according to waffle iron manufacturer’s instructions. This recipe can be adapted to make pancakes by leaving out 1 egg and 2 tablespoons of butter. Cook pancake batter in a sauté pan until bubbles pop and do not re-form, then flip and cook until firm. Serve with chopped mango and 1 scoop of ice cream or frozen yogurt.",
                Season = "summer"
            });
            Recipes.Add(new Recipe
            {
                ID = 4,
                Name = "mango spinach salad",
                Photo = "Images/Recipes/MangoSpinachSalad.jpg",
                Ingredients = "Crispy shallots: 1 shallot, 1 cup flour, 2 teaspoons salt, 1 teaspoon freshly cracked black pepper, 1 teaspoon paprika, 1 cup vegetable oil. Vinaigrette: ¼ cup olive oil, 2 tablespoons champagne vinegar, ¼ teaspoon salt, ¼ teaspoon pepper. Salad: 5 oz. fresh baby spinach, 3 medium ripe mangoes, 4 oz. goat cheese, 1 cup honey roasted cashews.",
                Instructions = "Crispy shallots: Slice shallot into thin rings and mix dry ingredients together in a shallow bowl. Heat (medium to high) the oil in a small sauce pan. Prepare a plate with a paper towel. Dreg rings in flour mixture and cook in oil until brown and crispy. Remove to paper towel and set aside. Vinaigrette: combine vinegar, salt and pepper in a small bowl, whisk vigorously while slowly pouring oil in. Chop the mango into ½ inch squares and crumble the goat cheese. Combine all ingredients in a large bowl and toss gently until spinach leaves are coated.",
                Season = "spring"
            });
            Recipes.Add(new Recipe
            {
                ID = 5,
                Name = "mango bruschetta",
                Photo = "Images/Recipes/MangoBruschetta.jpg",
                Ingredients = "1 ripe firm avocado, 1 ripe firm mango, 1 yellow bell pepper, 3 large leaves basil, 1 green onion, ½ pound cooked bacon, 3 tablespoons olive oil, ½ tablespoon lime juice, salt and pepper, 1 baguette.",
                Instructions = "Preheat oven to 425°. Peel and de-seed the mango and avocado. De-seed the bell pepper. Cut each into ¼ inch cubes. Cut basil, green onion and bacon into thin strips. Mix these ingredients in a bowl with the olive oil and the lime juice, salt and pepper to taste. Cut baguette into half inch slices and lay out on a baking sheet. Use remaining olive oil to brush on the bread. Bake in the oven for 7-10 minutes, until brown and crusty on the top. Allow bread to cool for a few minutes and then spoon mango mixture on top.",
                Season = "winter"
            });
            Recipes.Add(new Recipe
            {
                ID = 6,
                Name = "mango crab crepes",
                Photo = "Images/Recipes/MangoCrabCrepe.jpg",
                Ingredients = "Crepes: 2 eggs, 1 cup milk, ¾ cup all-purpose flour, 2 tablespoons melted butter plus butter to coat pan. Filling: 1 tablespoon olive oil, 1 lb. Dungeness crab meat, 1 lb. minced rockfish or snapper, 3 green onions, 1 teaspoon paprika, 1 ripe mango. Topping: ¾ cup crème fraiche, ¼ cup whole milk, ¼ cup chopped chives.",
                Instructions = "Combine crepe ingredients in processor for 15 seconds. Refrigerate for one hour to eliminate bubbles. Whisk crème fraiche and milk together and set aside. Over medium heat cook onions slightly in oil, then add fish, crab and paprika and sauté until cooked. Remove from heat and set aside.  Pour ¼ cup of crepe batter in the center of a small buttered pan and swirl around until coated in a thin layer. Cook for 30 seconds and flip, then cook for another ten seconds. Place crepe on serving plate and place thinly sliced mango down the center, spoon on a portion of crab mixture and roll up. Drizzle with crème fraiche and sprinkle with chives.",
                Season = "winter"
            });
            Recipes.Add(new Recipe
            {
                ID = 7,
                Name = "mango shrimp",
                Photo = "Images/Recipes/MangoShrimp.jpg",
                Ingredients = " 1 cup olive oil, 1 cup fresh tomato, ¼ cup parsley, 3 tablespoons lemon juice, 2 tablespoons Siracha (chili sauce), 3 cloves garlic, 1 teaspoon horseradish, 1 teaspoon oregano, 1 teaspoon salt, 1 teaspoon black pepper. Skewers: 8 bamboo (soaked in water 20 minutes prior to cooking) or metal skewers, 1 large ripe but firm mango, 2 lbs. uncooked shrimp, 1 tablespoon red chili powder.",
                Instructions = "Blend marinade ingredients in a food processor until liquefied. Divide quantity of sauce in half and set aside one half for dipping. De-vein and peel shrimp (leave tails attached) and put in a large zip locking bag. Pour half the sauce in the bag and push out any air before sealing. Put in fridge for at least two hours. Cut mango into 1 ½ inch square chunks. Remove shrimp from plastic and pat dry. Thread shrimp onto skewers alternating the mango between pieces. Lightly sprinkle skewers with chili powder. Grill or cook under a broiler for about two minutes on each side (for large shrimp cook longer).",
                Season = "autumn"
            });
            Recipes.Add(new Recipe
            {
                ID = 8,
                Name = "thai chicken curry",
                Photo = "Images/Recipes/ThaiChickenCurry.jpg",
                Ingredients = "1 pound chicken breast and/or thigh, 1 red pepper, 3 large carrots, 1 large broccoli floret, ½ cup rough chopped Thai basil, 3 tablespoons olive oil, salt and pepper. Sauce: 2 ripe mangoes, 3 cloves garlic, 1 tablespoon lime zest, 2 teaspoons chopped ginger, 1 red or green (hot, de-seeded) chili, 3 tablespoons soy sauce, 1 tablespoons Worcestershire sauce, 2 tablespoon coconut milk, 1 tablespoon Thai chili sauce, 1 tablespoon rice vinegar, ½ teaspoon turmeric, ½ teaspoon salt.",
                Instructions = "Cut chicken into strips, coat in olive oil and lightly sprinkle with salt and pepper. Pan-fry, grill or cook under a broiler until thoroughly cooked. Remove from heat and set aside. Make sauce by combining sauce ingredients in food processer and blending until completely mixed. Transfer to sauce pan and bring to a simmer. Chop vegetables. Add vegetables and chicken to pan and cook 5-10 minutes (vegetables should be warmed but crispy). Serve over rice or noodles and garnish with basil.",
                Season = "summer"
            });
            Recipes.Add(new Recipe
            {
                ID = 9,
                Name = "mango pork loin",
                Photo = "Images/Recipes/MangoPorkLoin.jpg",
                Ingredients = "1 large (1 ½- 2 lb.) pork tenderloin (trimmed of fat and silver skin) Marinade:  ½ cup fresh squeezed lemon juice, 1 ½ cup mango purée, ½ cup olive oil, 2 tablespoons honey, 3 cloves garlic, 2 teaspoons red chili flake, ¾ teaspoon salt, ¾ teaspoon freshly ground black pepper. Faro salad: 2 cups farro, 5 cups water, 1 cup halved cherry tomatoes, 1 cup cooked corn, 1 cup chopped parsley, 1 cup ½ inch cubed mango, ¼ cup sliced almonds, 2 teaspoons lemon juice, 1 tablespoon olive oil, salt and pepper to taste.",
                Instructions = "Combine marinade ingredients in a food processor and mince. Put all but 1 cup of the sauce in a zip lock bag and refrigerate at least an hour. Bring farro and water to a boil, reduce heat, cover and simmer for about 45 minutes (farro should remain slightly chewy). Strain any water and allow farro to cool. Preheat oven to 400 degrees. Remove pork from marinade, pat dry and sear in an oven proof skillet. Place in oven and cook until internal temperature is 145 degrees (about 35 minutes), basting with set aside marinade. Combine the salad ingredients and toss until coated. To serve, cut pork into medallions and drizzle basting liquid over top.",
                Season = "spring"
            });
            Recipes.Add(new Recipe
            {
                ID = 10,
                Name = "mango beef empanadas",
                Photo = "Images/Recipes/MangoEmpanadas.jpg",
                Ingredients = "2 tablespoons olive oil, 1 lb. ground beef, ½ cup chopped red onion, 1 cup chopped mango, 1 cup bell pepper, 1 cup sliced Spanish olives, ½ cup slivered almonds. Pepper-herb mixture: 1 poblano pepper, 1 serrano pepper, 1 cup cilantro, 1 cup  parsley, 3 cloves garlic, 6 green onions, 2 tablespoons lime juice, 2 teaspoons cumin, ½ teaspoon cayenne, 1 teaspoon oregano, ½ teaspoon salt, ½ teaspoon black pepper, standard recipe for pâte brisée or two rounds pre-made pie crust.",
                Instructions = "Pre-heat oven to 425 degrees (or per instructions with dough). Mince pepper-herb ingredients together, set aside. Heat oil in a large skillet, add onion and cook until soft. Add beef and brown. Add mango and pepper, cook for 5 minutes. Stir in pepper-herb mixture, olives and almonds, cook 3 minutes more, and remove from heat. Roll dough out, cut into circles, spoon beef mixture into middle and fold over into half-moon shapes. Roll edges, press with a fork and cut a small slash in top of pie to release steam.  Bake on a cookie sheet until dough is cooked.",
                Season = "winter"
            });
            Recipes.Add(new Recipe
            {
                ID = 11,
                Name = "mango ice pops",
                Photo = "Images/Recipes/MangoPopsicles.jpg",
                Ingredients = "1 cup mango purée, ¾ cup mango juice, ¼ cup orange juice, ¼ lime juice, 3 teaspoons cane sugar.",
                Instructions = "Combine all ingredients with a whisk or food processor. Pour into molds or ice cube trays, freeze. (If using ice cube trays freeze for 45 minutes then place toothpicks in the center of each cube.)",
                Season = "spring"
            });
            Recipes.Add(new Recipe
            {
                ID = 12,
                Name = "candied mango",
                Photo = "Images/Recipes/CandiedMango.jpg",
                Ingredients = "2 cups fresh mango, 1 cup fresh pineapple, 1 cup fresh papaya, 2 cups water, 5 cups cane sugar.",
                Instructions = "Cut fruit into one inch cubes. Place on a cooling rack, making sure pieces are spread out. Place the rack over a cookie sheet and dehydrate in the oven at 170 degrees for about 6 hours. Dehydration time depends on the moisture in the fruit and the moisture in the air. The fruit needs to be dry, not completely dehydrated. Heat the water, dissolve 4 cups of the sugar in it and bring to a softball stage boil (235-238 degrees). Reduce heat and add dry fruit. Simmer for about ½ hour (until fruit is translucent), do not stir. Remove from liquid, toss in the remaining sugar and return to 170 degree oven until completely dry.",
                Season = "spring"
            });
            Recipes.Add(new Recipe
            {
                ID = 13,
                Name = "coconut sticky rice",
                Photo = "Images/Recipes/MangoStickyRice.jpg",
                Ingredients = "2 ripe firm mangoes, 2 cups glutinous (sweet) rice, 1 can coconut milk, 2/3 cup water, 3 tablespoons toasted shredded coconut (unsweetened), 2 tablespoons powdered sugar, ½ tablespoon black sesame seeds, 1 tablespoon coconut flake.",
                Instructions = "Rinse the rice until water runs clear. Soak overnight. Combine rice, 1/3 cup of the coconut milk and water in a sauce pan and cook at a gentle boil for 5 minutes. Reduce heat to simmer. Stir well and cover with a tight fitting lid. Leave on low heat for 20 minutes. Cut the mango into thin slices and fan out on four plates. In a small sauce pan bring remainder of coconut milk to a boil, whisk in sugar. When thoroughly mixed remove from heat. Pack cooked rice into four small bowls or ramekins to shape, and then release at apex of plated mango. Spoon warm coconut milk/sugar sauce over top and garnish with sesame seeds and toasted coconut.",
                Season = "summer"
            });
            Recipes.Add(new Recipe
            {
                ID = 14,
                Name = "rum mango parfait",
                Photo = "Images/Recipes/MangoParfait.jpg",
                Ingredients = "4 cups crushed ginger snaps, 3 large ripe mangoes, 2 cups dried cherries, 3 cups brandy, 3 cups rum plus 1 tablespoon, 1 cup mango purée, 1 cup mascarpone cheese, 1 tablespoon honey, 1 pint heavy cream, tablespoon confectioner’s sugar.",
                Instructions = "Cut mango into ½ inch cubes, place in bowl with the 1 ½ cups of rum. Place cherries in a bowl with the brandy and let both stand at least 12 hours. In a mixing bowl or food processor combine the mascarpone, mango purée and honey until color is consistent. In a food processor (using the whipping attachment) or with a wire whisk combine the tablespoon of rum, sugar and cream and beat until whipped cream. Strain liquid from fruit (save to use in cocktails). Layer the parfait in a tall clear glass in any order you like, reserving the whipped cream for the final layer only.",
                Season = "winter"
            });
            Recipes.Add(new Recipe
            {
                ID = 15,
                Name = "mango bars",
                Photo = "Images/Recipes/MangoCookies.jpg",
                Ingredients = "Curd: 2 large very ripe mangoes, 2 tablespoons of lemon juice, ½ cup sugar, four egg yolks, ½ cup butter cut into pieces. Bars: ¾ cup unsalted butter (1 ½ sticks), 1 ¼ cup all-purpose flour, ¾ cup cane sugar, ¼ cup unsweetened coconut flakes, 1 tablespoon lemon zest.",
                Instructions = "Curd: Blend mango, lemon juice and sugar in a processer. Add egg yolk and process 5 seconds longer. In a metal bowl, over simmering water whisk mixture until thick enough to hold lines from whisk. Remove from heat and slowly stir in butter, strain through cheesecloth, transfer to clean container and refrigerate for six hours. Bars: Preheat oven to 425 degrees. Combine the butter, sugar and flour until mixture forms small crumbles. Press ¾ of mixture into bottom of a 9x13 baking pan. Bake crust for 10 minutes, and then cool. Spread mango curd evenly over crust, sprinkle remaining dough, coconut and zest over top and bake another 30 minutes.",
                Season = "autumn"
            });
            Recipes.Add(new Recipe
            {
                ID = 16,
                Name = "key mango pie",
                Photo = "Images/Recipes/MangoTart.jpg",
                Ingredients = "Crust: 1 ½ cups fine graham cracker crumbs, ½ cup granulated cane sugar, 4 tablespoons (½ stick) melted butter. Filling: 2 cans sweetened condensed milk, ¾ cup fresh key lime juice (if not possible regular lime juice will work), ¼ cup mango purée, 2 whole eggs plus 2 egg yolks, ¾ cup chopped (¼ inch cubes) mango. Topping: 1 pint heavy cream, 1 tablespoon confectioner’s sugar, 1 teaspoon lime zest, 2 limes cut into wheels.",
                Instructions = "Preheat oven to 375 degrees. Mix graham cracker crumbs, sugar and butter until well distributed. Press into a 9-inch pie pan. Bake for 20 minutes, remove and allow to cool. Make filling by whisking condensed milk, lime juice, mango purée and egg (including egg yolks) together until blended well. Stir in fresh mango. Lower oven temperature to 325 degrees. Pour filling into cooled crust and bake for 15 minutes. Chill in refrigerator for 3 hours. Whisk heavy cream, confectioner’s sugar and lime zest until mixture becomes whipped cream, add a dollop of cream and a lime wheel to each slice of pie.",
                Season = "autumn"
            });
            Recipes.Add(new Recipe
            {
                ID = 17,
                Name = "mango panna cotta",
                Photo = "Images/Recipes/MangoPudding.jpg",
                Ingredients = "1 tablespoon powdered agar-agar (or 1 tablespoon powdered gelatin), 3 tablespoons room temperature water, 1 cup mango purée, ½  cups mango juice, 3 cups chilled heavy cream, 1 teaspoon vanilla extract,  ¼ cup confectioner’s sugar plus 1 tablespoon, 2 cups sliced strawberries, 1 tablespoon lemon juice.",
                Instructions = "Sprinkle agar-agar evenly over water and set aside for 10 minutes. Bring the vanilla, mango purée and juice a gentle boil for 5 minutes, remove from heat and whisk in agar-agar, making sure it is completely dissolved. Strain mixture into a bowl that is in a cold water bath. Stir until mixture thickens, and then remove from cold. Dissolve ¼ cup confectioner’s sugar in the cream and stir into mango mixture. Once incorporated, pour into 6 ramekins and chill for 4 hours. In a small bowl mix the strawberries, remaining sugar and lemon juice. Place ramekins in warm water to release set panna cotta. Turn out on plate and spoon berries over top.",
                Season = "summer"
            });
            Recipes.Add(new Recipe
            {
                ID = 18,
                Name = "blue mango crumble",
                Photo = "Images/Recipes/MangoCrumble.jpg",
                Ingredients = "Filling: 3 cups chopped mango, 3 cups blueberries, 3 tablespoons all-purpose flour, 2 tablespoons cane sugar. Topping: 1 cup flour, ½ cup brown sugar, ¾  cup uncooked oats, ¼ teaspoon nutmeg, ½ cup (1 stick) melted butter,  ¼ cup finely chopped macadamia nuts, , 1 pint vanilla ice cream.",
                Instructions = "Preheat oven to 350 degrees. Mix filling ingredients in a bowl, mix gently and distribute mixture evenly in 4 large ramekins or small pie pans. Combine dry topping ingredients (except for nuts), add butter and mix until pea sized lumps are formed.  Stir in nuts and spoon on top of fruit mixture. Bake for 35 minutes. Serve warm with a scoop of ice cream. ",
                Season = "winter"
            });
            Recipes.Add(new Recipe
            {
                ID = 19,
                Name = "mango cupcakes",
                Photo = "Images/Recipes/MangoCupcakes.jpg",
                Ingredients = "Cupcakes: 1 ½ cups all-purpose flour, 2 teaspoons baking powder, ½ teaspoon salt, ½ cup soft butter (1 stick), ½ cup sugar, 2 eggs, ¾ cup white chocolate chips, 1 teaspoon vanilla, 1 cup milk. Frosting: 2 cups mango purée, 3 cups confectioner’s sugar, ½ cup soft butter (1 stick), 1 teaspoon vanilla.",
                Instructions = "Preheat oven to 325 degrees. Prepare muffin pan with cupcake liners (18 of them). Mix dry cupcake ingredients in a medium sized bowl (except for sugar), and set aside. In a metal bowl over a simmering saucepan melt chocolate until smooth. In a separate bowl cream butter and sugar, beat in eggs, chocolate and vanilla. Slowly (and alternately) mix in milk and dry mixture until fully incorporated. Pour batter into muffin pan and bake until toothpick in the center comes out clean (20 minutes). For frosting cream butter, sugar and vanilla, and then slowly add mango purée.",
                Season = "autumn"
            });
            Recipes.Add(new Recipe
            {
                ID = 20,
                Name = "banana rum cake",
                Photo = "Images/Recipes/BananaRumCake.jpg",
                Ingredients = "Cake batter: 3 bananas (mashed), 1 ¾ cup all-purpose flour, 2 teaspoons baking powder, ½ teaspoon cinnamon, ½ teaspoon nutmeg, ¼ teaspoon salt, ½ cup soft butter (1 stick), 2/4 cup cane sugar, 2 eggs, 2 tablespoons dark rum, ½ teaspoon vanilla, ¾ cup milk. Icing: 2 cups confectioner’s sugar (sifted) 1 cup mango juice.",
                Instructions = "Preheat oven to 350 degrees. Whisk dry batter ingredients (except for sugar). In a separate bowl, cream butter and sugar until fully incorporated. Slowly add eggs, beating well and then add rum and vanilla. Slowly (and alternately) beat in flour mixture and milk until all ingredients are barely incorporated. Pour batter into a non-stick (or buttered) loaf pan and bake until a pick in the middle comes out clean (40 minutes). To make icing, mix juice and sugar until sugar is dissolved. Allow cake to cool, remove from pan and spoon icing over the top.",
                Season = "spring"
            });
            Recipes.Add(new Recipe
            {
                ID = 21,
                Name = "mango sorbet",
                Photo = "Images/Recipes/MangoSorbet.jpg",
                Ingredients = "4 cups mango purée, ½ cup simple syrup (plus ½ cup for sweeter sorbet), 3 tablespoons fresh lime juice.",
                Instructions = "Combine ingredients and place in ice cream maker, follow manufactures instructions for your ice cream machine.  Make sure to churn slowly and continuously for the recommended time, to ensure that large ice crystals do not form.",
                Season = "summer"
            });
            mangoDb.Recipes.InsertAllOnSubmit<Recipe>(Recipes);
            mangoDb.SubmitChanges();
        }

        #endregion


        #region CreateFacts

        private void CreateFacts()
        {
            Facts.Add(new Fact 
            { 
                ID = 1, 
                Name = "mango mania", 
                Photo = "Images/Facts/MangoMania.jpg", 
                Body = "Humans first cultivated mangoes on the Indian sub-continent over 4,000 years ago. Cultivation of the fruit had spread to Southeast Asia by the 4th century BC. As a result of these two ancient originations there are two cultivar classifications for mango: Indian and Indochinese. There are however hundreds of mango cultivars. Worldwide the most popular cultivar is the Tommy Atkins, renowned for its disease resistance and transportability, if not for its flavor. Mangoes are produced in nearly every tropical and sub-tropical country in the world. Known in some circles as the “king of fruits” mango is popular everywhere."
            });
            Facts.Add(new Fact
            {
                ID = 2,
                Name = "mango, a love story",
                Photo = "Images/Facts/MangoLove.jpg",
                Body = "The genus Mangifera is one of about 35 tropical fruit trees that belong to the Anacardiaceae family of flowering plants, which are characterized by their resinous bark and caustic oils. Surprisingly, the friendly mango belongs to the same family as poison ivy. Mango trees can live for hundreds of years and grow up to 100 feet tall with a 130 foot canopy. The leaves are evergreen and the mildly scented flowers are red-yellow. It is the love affair between these exclusively male or hermaphroditic blossoms and wild insects that create the luscious fleshy drupe that is renowned all over the world."
            });
            Facts.Add(new Fact
            {
                ID = 3,
                Name = "mango is good for you",
                Photo = "Images/Facts/MangoGood.jpg",
                Body = "Mangoes, are not only an excellent source of dietary fiber, but are also rich in nutrients.  Up to 76% of the daily recommended intake of vitamin C can be found in 6 ounces of mango, as well as the highest concentrations of carotene to be found in fruit. Mangoes also provide significant amounts of vitamin E, niacin, calcium and iron to healthy diets. The flesh and extracts of mango skin and tree bark feature in various scientific tests and have been found to inhibit prostate and skin cancers in laboratory models. The anti-oxidant properties of mango are being tested as a treatment for certain blood ailments."
            });
            Facts.Add(new Fact
            {
                ID = 4,
                Name = "the venerated mango",
                Photo = "Images/Facts/MangoVenerated.jpg",
                Body = "The mango first appeared as religiously significant over 2,000 years ago in the text of the ancient Hindu Vedas. Hindu mythology holds that the mango tree is an earthly manifestation of Prajapti, the god of creation. Mango blossoms are used in the worship rites of Saraswati, the goddess of knowledge, art and music. Devotees to the goddess Parvati claim that a mango tree in the courtyard of Ekambaranathar temple in India is over 3000 years old. Among the ethnic Tamil Nadu the mango, jackfruit and banana are Mukkani, or the three royal Hindu fruits."
            });
            Facts.Add(new Fact
            {
                ID = 5,
                Name = "joie de mango",
                Photo = "Images/Facts/MangoJoie.jpg",
                Body = "Throughout the Indian subcontinent mango leaves are used to decorate weddings and other celebratory occasions, like the Ganesha Chaturthi. Ganesha is the god of wisdom and prosperity and is thought to take bad fortune with him as he leaves the festivities. He is sometimes depicted holding a perfectly ripe mango as a symbol of his devotee’s potential perfection. In Australia the annual appearance of the mango fruit hails the beginning of summer, and the first ripe fruits of the season are auctioned off for charity. In Barbados the local morning practice of swimming in the sea is seasonally enhanced by the ritual of eating mangoes in the sea. "
            });
            Facts.Add(new Fact
            {
                ID = 6,
                Name = "mangoes today",
                Photo = "Images/Facts/MangoCulture.jpg",
                Body = "India, Pakistan, the Philippines have all declared the mango their national fruit. India is the world’s largest mango exporter at around 15 million tons per year. Although the United States imports over 250,000 tons of mangoes annually, subsequent to 2007 most of those came from Mexico and South America because the U.S. had an import ban on Indian mangoes. In what is referred as the mango-for-bikes deal, the U.S. lifted the ban in exchange for India’s agreement to allow the Harley-Davidson motorcycles into Indian markets. Over 39,000,000 tons of mangoes are produced in the world annually."
            });
            Facts.Add(new Fact
            {
                ID = 7,
                Name = "mango spirits",
                Photo = "Images/Facts/MangoSpirits.jpg",
                Body = "The popularity of mango infused spirits world-wide has risen dramatically in the last five years. In 2007 Absolut released a limited edition mango and black pepper vodka called New Orleans and in 2009 put its simple mango infusion on the market.  Most of the major players in flavored vodkas also have a version on the market. Mango is poised to move on the rum market next. A simple and delicious home infusion can be made by soaking the chopped fruit of two mangoes with a pint of spiced rum for 24 hours, and then straining. The rum can be used for cocktails and the mango for recipes or eating as is."
            });
            Facts.Add(new Fact
            {
                ID = 8,
                Name = "the culinary mango",
                Photo = "Images/Facts/MangoCulinary.jpg",
                Body = "The unique and sun-sweet flavor of mango makes it a popular ingredient in both sweet and savory dishes. It is best to use mango raw because cooking the fruit can have a negative impact on flavor, as can ripeness and variety. The fresh fruit is at its peak when the stem end smells strongly of fruit and the flesh is firm but yielding.  The Alphonso cultivar is considered the best type for cooking because of its flavor concentration and sweetness. Most store bought purées are of this variety. Mango extract can be used to enhance flavor. The addition of peppercorns to custard, removed before setting, can also help retain mango essence."
            });
            Facts.Add(new Fact
            {
                ID = 9,
                Name = "a mango how-to guide",
                Photo = "Images/Facts/MangoHowTo.jpg",
                Body = "The best way to eat a mango is to tear away the peel and bite directly into flesh. However, occasions such as recipe use and the act of sharing call for more elegant preparation. The most popular way to extract cubes of mango is to use a large knife to cut the two flat sides lengthwise, on the sides of the seed. The flesh is then crosshatched with the peel side down, and popped inside out. The chunks can easily be trimmed from the inside of the skin. Mango fruit flowers are created by removing skin with a vegetable peeler and cutting downward to create thin, alternating chunks. The chunks are pushed outward to create petals."
            });
            Facts.Add(new Fact
            {
                ID = 10,
                Name = "mango crop report",
                Photo = "Images/Facts/CropReport.jpg",
                Body = "The National Mango Board in the USA is a national promotion and research organization, supported by assessments from domestic and imported mangoes. The board’s mission is to increase awareness and consumption of fresh mangoes in the USA, and includes producing the Mango Crop Report, every 7 to 14 days. The Mango Crop Report includes information about shipping projections, volume of mangoes arrived in the USA, varieties shipping from each country, as well as recent pricing information by port, variety and size. The document is a rich source of detailed information about the mango crop."
            });
            mangoDb.Facts.InsertAllOnSubmit<Fact>(Facts);
            mangoDb.SubmitChanges();
        }

        #endregion


        #region CreateCocktails

        private void CreateCocktails()
        {
            Cocktails.Add(new Cocktail 
            { 
                ID = 1, 
                Name = "mangollini", 
                Photo = "Images/Cocktails/mangollini.jpg", 
                Ingredients = "1½ oz. mango purée, 3 oz. Prosecco.", 
                Instructions = "Pour purée into champagne flute. Top with Prosecco. Stir.",
                Season = "summer", 
            });
            Cocktails.Add(new Cocktail
            {
                ID = 2,
                Name = "mangria",
                Photo = "Images/Cocktails/Mangria.jpg",
                Ingredients = "1 bottle rosé, 1 pint brandy, 1 large mango, 1 peach, 1 orange, ½ pound red grapes.",
                Instructions = "Peel and cut mango, peach and orange into ½ inch pieces. Combine with grapes, rosé and brandy in a large pitcher or bowl and let stand for 12 hours. Serve in a hurricane glass.",
                Season = "summer",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 3,
                Name = "mango cosmopolitan",
                Photo = "Images/Cocktails/MangoCosmo.jpg",
                Ingredients = "1½ oz. mango vodka, ½ oz. Cointreau, ½ oz. fresh lime juice, ½ oz. cranberry juice.",
                Instructions = "Combine all ingredients in a shaker filled with ice. Shake and strain into a martini glass. Garnish with a lime wedge.",
                Season = "autumn",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 4,
                Name = "captain midnight",
                Photo = "Images/Cocktails/CaptainMidnight.jpg",
                Ingredients = "1½ oz. vodka, 1½ oz. mango purée, 1 oz. blackberry purée, ½ oz. limoncello.",
                Instructions = "Spoon blackberry purée into the bottom of a martini glass. Combine vodka, mango purée and limoncello in a shaker filled with ice. Shake and strain carefully down the side of the glass so as to not stir up the blackberry purée. Garnish with a fresh blackberry picked to a mango wedge.",
                Season = "summer",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 5,
                Name = "mango jello shot",
                Photo = "Images/Cocktails/JelloShot.jpg",
                Ingredients = "2½ cups chilled vanilla vodka, 1 box (4 tablespoons) unflavored gelatin, 1½ cups mango juice, ½ cup chilled mango purée.",
                Instructions = "While heating 1 cup of mango juice to a boil, sprinkle gelatin over the remaining ½ cup mango juice let stand for 1 minute. Add boiling juice to gelatin mixture and stir until gelatin is completely dissolved. Stir in vodka and purée and pour mixture into a 9 x 13 baking sheet. Refrigerate until firm (three hours). Cut into blocks or shapes. Keep cold until service, as the gelatin will melt.",
                Season = "winter",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 6,
                Name = "oshun",
                Photo = "Images/Cocktails/Oshun.jpg",
                Ingredients = "1½ oz. Yazi ginger vodka, 1 oz. mango juice, ½ oz. Amaretto, ½ oz. lemon juice.",
                Instructions = "Combine all ingredients in a shaker full of ice, shake and strain into a cordial glass.",
                Season = "spring",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 7,
                Name = "konomi",
                Photo = "Images/Cocktails/Konomi.jpg",
                Ingredients = "2 oz. dry sake, 1 teaspoon matcha green tea, 2½ oz. hot water, ½ oz. lemongrass syrup (make by gently simmering cut lemongrass in 1 cup of water for a half hour, strain and mix with equal parts sugar while still hot), ½ oz. Suntory mango liqueur (if not available, make mango syrup following the same process as with lemongrass syrup).",
                Instructions = "In a highball glass stir the matcha into the hot water, allow to steep for one minute, add remaining ingredients and stir well.",
                Season = "summer",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 8,
                Name = "bridgetown cooler",
                Photo = "Images/Cocktails/BridgetownCooler.jpg",
                Ingredients = "6 oz. Mt. Gay rum, 6 oz. mango vodka, 3 oz. pineapple juice, 3 oz. coconut milk, 3 oz. guava juice, 1 pitted and peeled mango, 1 peeled banana, 1 peeled orange, 1 peeled lime, 1 tray of ice cubes.",
                Instructions = "Combine all ingredients in a blender and blend until smooth. Pour into hurricane glasses. Garnish with a maraschino cherry picked to a pineapple wedge.",
                Season = "autumn",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 9,
                Name = "saraswati vesper",
                Photo = "Images/Cocktails/SaraswatiVesper.jpg",
                Ingredients = "3 oz. gin, 1 oz. mango vodka, ½ oz. Lillet, 2 dashes orange bitters.",
                Instructions = "Combine ingredients in a shaker full of ice. Shake and strain into a martini glass. Garnish with a lemon twist.",
                Season = "spring",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 10,
                Name = "mangotini",
                Photo = "Images/Cocktails/Mangotini.jpg",
                Ingredients = "1½ oz. gin, 2 oz. mango juice, ½ oz. lemon juice, ½ oz. simple syrup, 1 egg white, 2 drops orange flower water, ½ oz. soda water.",
                Instructions = "Combine all ingredients except for soda in a shaker filled with ice. Shake vigorously for at least one minute. Strain into Collins (tall, narrow) glass. Top with soda. Garnish with a candied flower or a lemon twist.",
                Season = "autumn",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 11,
                Name = "17th parallel",
                Photo = "Images/Cocktails/17thParallel.jpg",
                Ingredients = "1½ oz. gin, 2 oz. mango juice, ½ oz. lemon juice, ½ oz. Grand Marnier, 2 oz. sparkling wine.",
                Instructions = "Combine all ingredients except for the sparkling wine in a shaker full of ice. Shake and strain into a martini glass. Top with sparkling wine and garnish with a lemon twist.",
                Season = "winter",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 12,
                Name = "capifruta",
                Photo = "Images/Cocktails/CapiFruta.jpg",
                Ingredients = "1½ oz. cachaça, 3 lime wedges, 3 chunks of ripe mango, 1 oz. soda, 1 teaspoon cane sugar.",
                Instructions = "Put fruit and sugar in the bottom of a shaker and fill with ice. Using a muddler crush ice and pulp fruit. Add cachaça and shake well. Pour into old-fashioned glass and add ice to fill to rim. Top with soda.",
                Season = "winter",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 13,
                Name = "mango rum punch",
                Photo = "Images/Cocktails/MangoRumPunch.jpg",
                Ingredients = "8 oz. (1 cup) lime juice, 16 oz. (2 cups) simple syrup, 24 oz. (3 cups) spiced rum, 32 oz. (4 cups) mango juice, 5 heavy dashes of bitters, freshly ground nutmeg.",
                Instructions = "Combine all ingredients except for nutmeg in a large pitcher and stir well. Pour into tall glasses filled with lots of ice. Garnish with a sprinkle of nutmeg, a maraschino cherry and an orange slice.",
                Season = "autumn",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 14,
                Name = "pilar daiquiri",
                Photo = "Images/Cocktails/PilarDaiquiri.jpg",
                Ingredients = "1½ oz. light rum, ¼ oz. cherry brandy, 1 oz. lime juice, 3 oz. mango juice.",
                Instructions = "Combine all ingredients in a blender. Pour into a highball or hurricane glass. Garnish with a lime wedge.",
                Season = "summer",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 15,
                Name = "dark & tropical stormy",
                Photo = "Images/Cocktails/MangoDarkStormy.jpg",
                Ingredients = "1½ oz. Goslings rum, ½ oz. ginger simple syrup (to make: simmer one cup of water with ¼ cup peeled and chopped ginger for a half hour, strain and dissolve an equal part of sugar into the hot ginger water), 3 dashes of Angostura bitters, juice from 1 lime wedge, 1½ oz. mango juice, 1 oz. soda.",
                Instructions = "Combine rum, simple syrup, bitters and mango juice in a shaker full of ice. Strain into an old-fashioned glass full of fresh ice. Squeeze lime wedge and drop into glass top with soda.",
                Season = "spring",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 16,
                Name = "pineapple mango mojito",
                Photo = "Images/Cocktails/PineappleMangoMojito.jpg",
                Ingredients = "1½ oz. light rum, ½ oz. pineapple juice, 1 oz. mango juice, 4 fresh lime wedges, 12 cup mint leaves, 1½ oz. soda.",
                Instructions = "Tear mint leaves and drop into the bottom of a shaker with lime wedges. Top with ice and muddle until ice is crushed. Refill ice. Add rum, pineapple juice and mango juice. Shake and pour into a pint glass. Top with soda. Garnish with a lime wedge and a mint sprig.",
                Season = "winter",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 17,
                Name = "mangorita",
                Photo = "Images/Cocktails/Mangorita.jpg",
                Ingredients = "1½ oz. tequila, 1½ oz. lime juice, 1½ oz. mango purée, ½ oz. Grand Marnier, ½ cup ice.",
                Instructions = "Blend everything but the Grand Marnier in a blender. Pour into margarita or martini glass. Float the Grand Marnier on the top, garnish with a lime.",
                Season = "spring",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 18,
                Name = "mango pasión",
                Photo = "Images/Cocktails/MangoPasion.jpg",
                Ingredients = "1½ oz. tequila, ½ oz. St. Germain, 2 oz. cava (or any sparkling wine), 2 oz. mango juice.",
                Instructions = "Combine all ingredients except for the cava in a shaker full of ice. Shake well and strain in a highball glass full of fresh ice. Top with cava and garnish with an orange wheel and a cherry.",
                Season = "spring",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 19,
                Name = "mauritius derby",
                Photo = "Images/Cocktails/MauritiusDerby.jpg",
                Ingredients = "1½ oz. bourbon, 1 oz. mango purée, ½ cup mint leaves, ½ oz. simple syrup, 1½ oz. soda.",
                Instructions = "Tear mint leaves and drop into the bottom of a shaker. Add simple syrup and top with ice. Muddle until ice is crushed. Refill ice and add bourbon and mango purée. Shake and pour into a highball glass. Top with soda, and garnish with a mint sprig.",
                Season = "winter",
            });
            Cocktails.Add(new Cocktail
            {
                ID = 20,
                Name = "mango cordial",
                Photo = "Images/Cocktails/MangoCordial.jpg",
                Ingredients = "1 scoop mango sorbet, 1 oz. Chambord.",
                Instructions = "Scoop sorbet into a short parfait style glass. Pour the Chambord gently down the side of the glass so it settles on the bottom. Garnish with a cherry and a mint leaf.",
                Season = "winter",
            });
            mangoDb.Cocktails.InsertAllOnSubmit<Cocktail>(Cocktails);
            mangoDb.SubmitChanges();
        }
        #endregion

    }
}
