﻿using System;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;

namespace MangoClient
{
    public partial class MainPage : PhoneApplicationPage
    {

        #region Init

        public MainPage()
        {
            InitializeComponent();
            DataContext = App.ViewModel;
        }

        #endregion


        #region OnNavigatedTo

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            SeasonalPanoItem.Header = App.ViewModel.Season + " highlights";
            CategoryList.SelectedIndex = -1;
            CategoryList.ItemsSource = App.ViewModel.Categories;
            SeasonalList.SelectedIndex = -1;
            SeasonalList.ItemsSource = App.ViewModel.SeasonalHighlights;
        }

        #endregion


        #region SelectionChanged

        private void CategoryList_SelectionChanged(
            object sender, SelectionChangedEventArgs e)
        {
            switch (CategoryList.SelectedIndex)
            {
                case 0:
                    App.ViewModel.LoadRecipes();
                    NavigationService.Navigate(
                        new Uri("/RecipesPage.xaml", UriKind.Relative));
                    break;
                case 1:
                    App.ViewModel.LoadFacts();
                    NavigationService.Navigate(
                        new Uri("/FactsPage.xaml", UriKind.Relative));
                    break;
                case 2:
                    App.ViewModel.LoadCocktails();
                    NavigationService.Navigate(
                        new Uri("/CocktailsPage.xaml", UriKind.Relative));
                    break;
                case 3:
                    NavigationService.Navigate(
                        new Uri("/GamePage.xaml", UriKind.Relative));
                    break;
            }
        }
       
        private void SeasonalList_SelectionChanged(
            object sender, SelectionChangedEventArgs e)
        {
            // When the user selects an item from the seasonal highlights list,
            // we must identify which table/page to navigate to, as well as which item.
            if (SeasonalList.SelectedIndex != -1)
            {
                SeasonalHighlight selectedItem = 
                    (SeasonalHighlight)SeasonalList.SelectedItem;
                String navigationString = String.Empty;
                if (selectedItem.SourceTable == "Recipes")
                {
                    App.ViewModel.LoadRecipes();
                    navigationString = 
                        String.Format("/RecipePage.xaml?ID={0}", selectedItem.ID);
                }
                else if (selectedItem.SourceTable == "Cocktails")
                {
                    App.ViewModel.LoadCocktails();
                    navigationString = 
                        String.Format("/CocktailPage.xaml?ID={0}", selectedItem.ID);
                }
                NavigationService.Navigate(
                    new System.Uri(navigationString, UriKind.Relative));
            }
        }

        #endregion

    }
}