﻿using Microsoft.Phone.Controls;
using System.Windows.Navigation;
using System;
using System.Linq;
using Microsoft.Phone.Shell;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows;

namespace MangoClient
{
    public partial class RecipePage : PhoneApplicationPage
    {

        #region Fields

        private int recipeID;
        private Recipe thisRecipe;
        private String thisPageUri;
        private ShellTile tile;

        #endregion


        #region Init

        public RecipePage()
        {
            InitializeComponent();
        }

        private Uri GetPinImageForTheme(PinState pinState)
        {
            Uri pinUri = null;
            Visibility dark = (Visibility)Resources["PhoneDarkThemeVisibility"];
            string uriString = "Images/Pins/";
            if (dark == Visibility.Visible)
            {
                uriString += (pinState == PinState.Pin) ? "Pin_white.png" : "Unpin_white.png";
                pinUri = new Uri(uriString, UriKind.Relative);
            }
            else
            {
                uriString += (pinState == PinState.Pin) ? "Pin_black.png" : "Unpin_black.png";
                pinUri = new Uri(uriString, UriKind.Relative);
            }
            return pinUri;
        }

        #endregion


        #region OnNavigatedTo

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            recipeID = int.Parse(NavigationContext.QueryString["ID"]);

            // Get the data for this Recipe.
            App.ViewModel.LoadRecipes();
            foreach (Recipe r in App.ViewModel.Recipes)
            {
                if (r.ID == recipeID)
                {
                    DataContext = thisRecipe = r;
                    break;
                }
            }

            // Check if the user has pinned this recipe tile to the Start page.
            thisPageUri = String.Format("/RecipePage.xaml?ID={0}", recipeID);
            tile = ShellTile.ActiveTiles.FirstOrDefault(
                x => x.NavigationUri.ToString().Contains(thisPageUri));

            ImageBrush pinBrush = (ImageBrush)PinUnpin.Background;
            if (tile != null)
            {
                pinBrush.ImageSource = new BitmapImage(
                    GetPinImageForTheme(PinState.Unpin));
            }
            else
            {
                pinBrush.ImageSource = new BitmapImage(
                    GetPinImageForTheme(PinState.Pin));
            }
            PinUnpin.Background = pinBrush;
        }

        #endregion


        #region PinUnpin_Click

        private void PinUnpin_Click(object sender, RoutedEventArgs e)
        {
            // If this tile doesn't already exist, create it.
            ImageBrush pinBrush = (ImageBrush)PinUnpin.Background;
            tile = ShellTile.ActiveTiles.FirstOrDefault(
                x => x.NavigationUri.ToString().Contains(thisPageUri));
            if (tile == null)
            {
                // Set up the new tile based on the current Recipe data.
                StandardTileData tileData = new StandardTileData
                {
                    BackgroundImage = new Uri(
                        thisRecipe.Photo, UriKind.RelativeOrAbsolute),
                    Title = thisRecipe.Name,
                    BackTitle = "Lovely Mangoes!",
                    BackBackgroundImage = 
                    new Uri("Images/BackTile.png", UriKind.Relative)
                };

                // Toggle the Pin/Unpin button to the 'Unpin' image.
                pinBrush.ImageSource = 
                    new BitmapImage(GetPinImageForTheme(PinState.Unpin));

                // Create the tile and pin to start. Note this will deactivate the app.
                ShellTile.Create(
                    new Uri(thisPageUri, UriKind.Relative), tileData);
            }
            else
            {
                // This tile already exists, so the user must have asked us to unpin it.
                tile.Delete();
                pinBrush.ImageSource = 
                    new BitmapImage(GetPinImageForTheme(PinState.Pin));
            }
            PinUnpin.Background = pinBrush;
        }

        #endregion

    }

    public enum PinState { Pin, Unpin};

}