﻿using System;
using System.Linq;
using System.Collections.Generic;

namespace MangoClient
{
    public class MainViewModel
    {

        #region Fields

        private MangoDataContext mangoDb;

        #endregion


        #region Properties

        private bool isDataLoaded;
        public bool IsDataLoaded
        {
            get { return isDataLoaded; }
        }

        private string season;
        public string Season
        {
            get { return season; }
        }

        private List<Category> categories;
        public List<Category> Categories
        {
            get { return categories; }
        }

        private List<Recipe> recipes;
        public List<Recipe> Recipes
        {
            get { return recipes; }
        }

        private List<Fact> facts;
        public List<Fact> Facts
        {
            get { return facts; }
        }

        private List<Cocktail> cocktails;
        public List<Cocktail> Cocktails
        {
            get { return cocktails; }
        }

        private List<SeasonalHighlight> seasonalHighlights;
        public List<SeasonalHighlight> SeasonalHighlights
        {
            get { return seasonalHighlights; }
        }

        #endregion


        #region Init

        public MainViewModel()
        {
            // Find out what season we're in.
            season = String.Empty;
            int currentMonth = DateTime.Now.Month;
            if (currentMonth >= 3 && currentMonth <= 5) season = "spring";
            else if (currentMonth >= 6 && currentMonth <= 8) season = "summer";
            else if (currentMonth >= 9 && currentMonth <= 11) season = "autumn";
            else if (currentMonth == 12 || currentMonth == 1 || currentMonth == 2) season = "winter";
        }

        #endregion


        #region LoadData

        internal void LoadData()
        {
            mangoDb = new MangoDataContext();
            if (!mangoDb.DatabaseExists())
            {
                mangoDb.CreateDatabase();
            }

            categories = new List<Category>();
            categories.Add(new Category { ID = 1, Name = "recipes" });
            categories.Add(new Category { ID = 2, Name = "fun facts" });
            categories.Add(new Category { ID = 3, Name = "cocktail bar" });
            categories.Add(new Category { ID = 4, Name = "mango, the game" });

            // Delay-load the Recipes, Facts and Cocktails, to speed up
            // app startup.
            //IQueryable<Recipe> recipesQuery = 
            //    from Recipe r in mangoDb.Recipes select r;
            //recipes = new List<Recipe>(recipesQuery);

            //IQueryable<Fact> factsQuery = 
            //    from Fact f in mangoDb.Facts select f;
            //facts = new List<Fact>(factsQuery);

            //IQueryable<Cocktail> cocktailsQuery = 
            //    from Cocktail t in mangoDb.Cocktails select t;
            //cocktails = new List<Cocktail>(cocktailsQuery);

            //var seasonalRecipes = from r in Recipes where r.Season == season 
            //                      select new { r.ID, r.Name, r.Photo };
            //var seasonalCocktails = from c in Cocktails where c.Season == season 
            //                        select new { c.ID, c.Name, c.Photo };

            var seasonalRecipes = from r in mangoDb.Recipes
                                  where r.Season == season
                                  select new { r.ID, r.Name, r.Photo };
            var seasonalCocktails = from c in mangoDb.Cocktails
                                    where c.Season == season
                                    select new { c.ID, c.Name, c.Photo };

            seasonalHighlights = new List<SeasonalHighlight>();
            foreach (var v in seasonalRecipes)
            {
                seasonalHighlights.Add(new SeasonalHighlight { 
                    ID = v.ID, Name = v.Name, Photo = v.Photo, SourceTable="Recipes" });
            }
            foreach (var v in seasonalCocktails)
            {
                seasonalHighlights.Add(new SeasonalHighlight { 
                    ID = v.ID, Name = v.Name, Photo = v.Photo, SourceTable = "Cocktails" });
            }

            isDataLoaded = true;
        }

        internal void LoadFacts()
        {
            if (facts == null || facts.Count == 0)
            {
                IQueryable<Fact> factsQuery =
                    from Fact f in mangoDb.Facts select f;
                facts = new List<Fact>(factsQuery);
            }
        }

        internal void LoadRecipes()
        {
            if (recipes == null || recipes.Count == 0)
            {
                IQueryable<Recipe> recipesQuery =
                    from Recipe r in mangoDb.Recipes select r;
                recipes = new List<Recipe>(recipesQuery);
            }
        }

        internal void LoadCocktails()
        {
            if (cocktails == null || cocktails.Count == 0)
            {
                IQueryable<Cocktail> cocktailsQuery =
                    from Cocktail t in mangoDb.Cocktails select t;
                cocktails = new List<Cocktail>(cocktailsQuery);
            }
        }

        #endregion

    }
}
