﻿using System.Data.Linq;
using System.Data.Linq.Mapping;
using System.ComponentModel;

namespace MangoClient
{
    public class MangoDataContext : DataContext
    {
        // This DB is readonly, so we can access it directly from the install folder.
        public MangoDataContext()
            : base("Data Source=appdata:/Mangolicious.sdf;File Mode=read only;")
        {
        }

        public Table<Recipe> Recipes;
        public Table<Fact> Facts;
        public Table<Cocktail> Cocktails;
        public Table<SeasonalHighlight> SeasonalHighlights;
    }


    #region Recipes

    [Table]
    public class Recipe
    {
        private int id;
        [Column(
            IsPrimaryKey = true, IsDbGenerated = true,
            DbType = "INT NOT NULL Identity", CanBeNull = false,
            AutoSync = AutoSync.OnInsert)]
        public int ID
        {
            get { return id; }
            set
            {
                if (id != value)
                {
                    id = value;
                }
            }
        }

        private string name;
        [Column(DbType = "NVARCHAR(32)")]
        public string Name
        {
            get { return name; }
            set
            {
                if (name != value)
                {
                    name = value;
                }
            }
        }

        private string photo;
        [Column(DbType = "NVARCHAR(255)")]
        public string Photo
        {
            get { return photo; }
            set
            {
                if (photo != value)
                {
                    photo = value;
                }
            }
        }

        private string ingredients;
        [Column(DbType = "NVARCHAR(512)")]
        public string Ingredients
        {
            get { return ingredients; }
            set
            {
                if (ingredients != value)
                {
                    ingredients = value;
                }
            }
        }

        private string instructions;
        [Column(DbType = "NVARCHAR(1024)")]
        public string Instructions
        {
            get { return instructions; }
            set
            {
                if (instructions != value)
                {
                    instructions = value;
                }
            }
        }

        private string season;
        [Column(DbType = "NVARCHAR(8)")]
        public string Season
        {
            get { return season; }
            set
            {
                if (season != value)
                {
                    season = value;
                }
            }
        }
    }

    #endregion


    #region Facts

    [Table]
    public class Fact
    {
        private int id;
        [Column(
            IsPrimaryKey = true, IsDbGenerated = true,
            DbType = "INT NOT NULL Identity", CanBeNull = false,
            AutoSync = AutoSync.OnInsert)]
        public int ID
        {
            get { return id; }
            set
            {
                if (id != value)
                {
                    id = value;
                }
            }
        }

        private string name;
        [Column(DbType = "NVARCHAR(32)")]
        public string Name
        {
            get { return name; }
            set
            {
                if (name != value)
                {
                    name = value;
                }
            }
        }

        private string photo;
        [Column(DbType = "NVARCHAR(255)")]
        public string Photo
        {
            get { return photo; }
            set
            {
                if (photo != value)
                {
                    photo = value;
                }
            }
        }

        private string body;
        [Column(DbType = "NVARCHAR(1024)")]
        public string Body
        {
            get { return body; }
            set
            {
                if (body != value)
                {
                    body = value;
                }
            }
        }
    }

    #endregion


    #region Cocktails

    [Table]
    public class Cocktail
    {
        private int id;
        [Column(
            IsPrimaryKey = true, IsDbGenerated = true,
            DbType = "INT NOT NULL Identity", CanBeNull = false,
            AutoSync = AutoSync.OnInsert)]
        public int ID
        {
            get { return id; }
            set
            {
                if (id != value)
                {
                    id = value;
                }
            }
        }

        private string name;
        [Column(DbType = "NVARCHAR(32)")]
        public string Name
        {
            get { return name; }
            set
            {
                if (name != value)
                {
                    name = value;
                }
            }
        }

        private string photo;
        [Column(DbType = "NVARCHAR(255)")]
        public string Photo
        {
            get { return photo; }
            set
            {
                if (photo != value)
                {
                    photo = value;
                }
            }
        }

        private string ingredients;
        [Column(DbType = "NVARCHAR(512)")]
        public string Ingredients
        {
            get { return ingredients; }
            set
            {
                if (ingredients != value)
                {
                    ingredients = value;
                }
            }
        }

        private string instructions;
        [Column(DbType = "NVARCHAR(1024)")]
        public string Instructions
        {
            get { return instructions; }
            set
            {
                if (instructions != value)
                {
                    instructions = value;
                }
            }
        }

        private string season;
        [Column(DbType = "NVARCHAR(8)")]
        public string Season
        {
            get { return season; }
            set
            {
                if (season != value)
                {
                    season = value;
                }
            }
        }
    }

    #endregion


    #region SeasonalHighlights

    // NOTE SeasonalHighlights is the one table in the DataContext that does not 
    // have a matching table in the SQL-CE DB. The data for this table is composed
    // at runtime from the SQL Cocktails and Recipes tables (SQL-CE doesn't support views).

    [Table]
    public class SeasonalHighlight
    {
        // Unlike the ID column in other tables, the ID column in the
        // SeasonalHighlights table is not an Identity column, nor a key,
        // it can be null, and it is not auto-generated.
        private int id;
        [Column(
            IsPrimaryKey = false, IsDbGenerated = false,
            DbType = "INT NOT NULL", CanBeNull = true,
            AutoSync = AutoSync.OnInsert)]
        public int ID
        {
            get { return id; }
            set
            {
                if (id != value)
                {
                    id = value;
                }
            }
        }

        private string sourceTable;
        [Column(DbType = "NVARCHAR(16)")]
        public string SourceTable
        {
            get { return sourceTable; }
            set
            {
                if (sourceTable != value)
                {
                    sourceTable = value;
                }
            }
        }

        private string name;
        [Column(DbType = "NVARCHAR(32)")]
        public string Name
        {
            get { return name; }
            set
            {
                if (name != value)
                {
                    name = value;
                }
            }
        }

        private string photo;
        [Column(DbType = "NVARCHAR(255)")]
        public string Photo
        {
            get { return photo; }
            set
            {
                if (photo != value)
                {
                    photo = value;
                }
            }
        }

        private string season;
        [Column(DbType = "NVARCHAR(8)")]
        public string Season
        {
            get { return season; }
            set
            {
                if (season != value)
                {
                    season = value;
                }
            }
        }
    }

    #endregion


    #region Categories

    // Category is a simple type, there is no corresponding
    // table in the database. 
    public class Category
    {
        private int id;
        public int ID
        {
            get { return id; }
            set
            {
                if (id != value)
                {
                    id = value;
                }
            }
        }

        private string name;
        public string Name
        {
            get { return name; }
            set
            {
                if (name != value)
                {
                    name = value;
                }
            }
        }
    }

    #endregion

}
